@@ -454,9 +454,17 @@ class SquareRootBijector(tfb.Bijector):
           name: str
               Name given to ops managed by this object.
         """
+        # Without these `parameters` the code won't be compatible with future versions
+        # of tfp:
+        # https://github.com/tensorflow/probability/issues/1202
+        parameters = dict(locals())
         with tf.name_scope(name) as name:
-            super().__init__(forward_min_event_ndims=0, validate_args=validate_args,
-                             name=name)
+            super().__init__(
+                forward_min_event_ndims=0,
+                validate_args=validate_args,
+                parameters=parameters,
+                name=name
+            )
 
     def _forward(self, x: Union[float, np.array, tf.Tensor]) -> tf.Tensor:
         """
